kuuko pushed a commit to branch master.

http://git.enlightenment.org/bindings/python/python-efl.git/commit/?id=8109cd62b44177f501a157b1cc01cf549ef98838

commit 8109cd62b44177f501a157b1cc01cf549ef98838
Author: Kai Huuhko <kai.huu...@gmail.com>
Date:   Mon Apr 14 13:45:30 2014 +0300

    Code cleanup: Spelling and grammar fixes
---
 efl/ecore/efl.ecore.pyx               |  2 +-
 efl/ecore/efl.ecore_exe.pxi           |  6 ++--
 efl/ecore/efl.ecore_fd_handler.pxi    |  4 +--
 efl/ecore/efl.ecore_file_download.pxi |  4 +--
 efl/ecore/efl.ecore_poller.pxi        |  2 +-
 efl/edje/efl.edje_edit_part_state.pxi |  1 +
 efl/elementary/cnp_callbacks.pxi      |  2 +-
 efl/elementary/configuration.pyx      |  2 +-
 efl/elementary/datetime_elm.pyx       |  6 ++++
 efl/elementary/diskselector.pyx       |  2 +-
 efl/elementary/gengrid_item_class.pxi |  2 +-
 efl/elementary/gengrid_widget.pxi     |  4 +--
 efl/elementary/genlist.pyx            |  6 ++--
 efl/elementary/genlist_item_class.pxi |  4 +--
 efl/elementary/genlist_widget.pxi     |  6 ++--
 efl/elementary/glview.pyx             |  2 +-
 efl/elementary/icon.pyx               |  2 +-
 efl/elementary/layout_class.pyx       |  4 +--
 efl/elementary/map.pyx                | 58 +++++++++++++++++------------------
 efl/elementary/naviframe.pyx          |  2 +-
 efl/elementary/object.pyx             |  4 +--
 efl/elementary/photocam.pyx           |  2 +-
 efl/elementary/radio.pyx              |  2 +-
 efl/elementary/slideshow.pyx          |  2 +-
 efl/elementary/toolbar.pyx            |  2 +-
 efl/elementary/window.pxd             |  2 +-
 efl/elementary/window.pyx             |  4 +--
 efl/emotion/efl.emotion.pyx           | 18 +++++------
 efl/ethumb/efl.ethumb_client.pyx      |  2 +-
 efl/evas/efl.evas.pyx                 |  4 +--
 efl/evas/efl.evas_object.pxi          |  4 +--
 efl/evas/efl.evas_object_box.pxi      |  4 +--
 efl/evas/efl.evas_object_image.pxi    |  2 +-
 efl/evas/efl.evas_object_smart.pxi    |  2 +-
 efl/evas/efl.evas_object_table.pxi    |  2 +-
 efl/evas/efl.evas_object_textgrid.pxi |  2 +-
 include/efl.ethumb.enums.pxd          |  2 +-
 include/efl.evas.enums.pxd            |  2 +-
 tests/edje/test_03_external.py        | 12 ++++----
 tests/edje/test_05_decorators.py      |  2 +-
 tests/evas/test_04_object_box.py      |  2 +-
 41 files changed, 103 insertions(+), 96 deletions(-)

diff --git a/efl/ecore/efl.ecore.pyx b/efl/ecore/efl.ecore.pyx
index a4290fa..9ea43ea 100644
--- a/efl/ecore/efl.ecore.pyx
+++ b/efl/ecore/efl.ecore.pyx
@@ -347,7 +347,7 @@ _orig_subprocess = None
 
 def subprocess_warning(*a, **ka):
     print("""    DEVELOPER WARNING:
-        Using subprocess (Popen and derivates) with Ecore is a bad idea.
+        Using subprocess (Popen and derivatives) with Ecore is a bad idea.
 
         Ecore will set some signal handlers subprocess module depends and this
         may cause this module to operate unexpectedly.
diff --git a/efl/ecore/efl.ecore_exe.pxi b/efl/ecore/efl.ecore_exe.pxi
index dd0ff44..c25d199 100644
--- a/efl/ecore/efl.ecore_exe.pxi
+++ b/efl/ecore/efl.ecore_exe.pxi
@@ -173,7 +173,7 @@ cdef class Exe(object):
     Note that the process handle is only valid until a child process
     terminated event is received.  After all handlers for the child
     process terminated event have been called, the handle will be
-    freed by Ecore. In this case the Python wrapper becames "shallow"
+    freed by Ecore. In this case the Python wrapper becomes "shallow"
     and all operations will fail or return bogus/dummy values,
     although it should not crash.
 
@@ -569,7 +569,7 @@ cdef class Exe(object):
         self.pause()
 
     def continue_(self):
-        """Send contine signal (SIGCONT) to executed process.
+        """Send continue signal (SIGCONT) to executed process.
 
         This resumes application previously paused with :py:meth:`pause`
 
@@ -583,7 +583,7 @@ cdef class Exe(object):
     def interrupt(self):
         """Send interrupt signal (SIGINT) to executed process.
 
-        .. note:: Python usually installs SIGINT hanlder to generate
+        .. note:: Python usually installs SIGINT handler to generate
                   *KeyboardInterrupt*, however Ecore will *override*
                   this handler with its own that generates
                   *ECORE_EVENT_SIGNAL_EXIT* in its main loop for the
diff --git a/efl/ecore/efl.ecore_fd_handler.pxi 
b/efl/ecore/efl.ecore_fd_handler.pxi
index e4627d4..227e4df 100644
--- a/efl/ecore/efl.ecore_fd_handler.pxi
+++ b/efl/ecore/efl.ecore_fd_handler.pxi
@@ -64,7 +64,7 @@ cdef class FdHandler(object):
     When the handler ``func`` is called, it must return a value of
     either *True* or *False* (remember that Python returns *None* if no value
     is explicitly returned and *None* evaluates to *False*). If it returns
-    *True*, it will continue to montior the given file descriptor, or if
+    *True*, it will continue to monitor the given file descriptor, or if
     it returns *False* it will be deleted automatically making any
     references/handles for it invalid.
 
@@ -199,7 +199,7 @@ cdef class FdHandler(object):
         return bool(ecore_main_fd_handler_active_get(self.obj, ECORE_FD_ERROR))
 
     def prepare_callback_set(self, func, *args, **kargs):
-        """Set a function to call becore doing the select() on the fd.
+        """Set a function to call before doing the select() on the fd.
 
         Expected signature::
 
diff --git a/efl/ecore/efl.ecore_file_download.pxi 
b/efl/ecore/efl.ecore_file_download.pxi
index 786ed95..ca27efe 100644
--- a/efl/ecore/efl.ecore_file_download.pxi
+++ b/efl/ecore/efl.ecore_file_download.pxi
@@ -150,7 +150,7 @@ def file_download(url, dst, completion_cb, progress_cb, 
*args, **kargs):
                           Expected signature::
                             completion_cb(file, status, *args, **kargs)
     :param progress_cb: The function to called while the download progress
-                        advance. Ecpected signature::
+                        advance. Expected signature::
                             progress_cb(file, dltotal, dlnow, uptotal, upnow, 
*args, **kargs): int
 
     :return: a new FileDownload instance
@@ -165,7 +165,7 @@ def file_download_abort(instance):
     instance.abort()
 
 def file_download_abort_all():
-    """This will abort all the download currently in progrss, use with caution.
+    """This will abort all the download currently in progress, use with 
caution.
     """
     ecore_file_download_abort_all()
 
diff --git a/efl/ecore/efl.ecore_poller.pxi b/efl/ecore/efl.ecore_poller.pxi
index 13e9887..fe0a420 100644
--- a/efl/ecore/efl.ecore_poller.pxi
+++ b/efl/ecore/efl.ecore_poller.pxi
@@ -58,7 +58,7 @@ cdef class Poller(Eo):
 
     :param interval: The poll interval
     :type interval: int
-    :param func: The cunction to call at every intervat
+    :param func: The function to call at every interval
     :type func: callable
     :param poll_type: The ticker type to attach the poller to. Must be 
ECORE_POLLER_CORE
     :type poll_type: Ecore_Poll_Type
diff --git a/efl/edje/efl.edje_edit_part_state.pxi 
b/efl/edje/efl.edje_edit_part_state.pxi
index f290e61..74ea00b 100644
--- a/efl/edje/efl.edje_edit_part_state.pxi
+++ b/efl/edje/efl.edje_edit_part_state.pxi
@@ -737,6 +737,7 @@ cdef class State:
         def __set__(self, align):
             self.text_align_set(*align)
 
+    # FIXME: These should be ellipsis, not elipsis. Was this API ever released?
     def text_elipsis_get(self):
         return edje_edit_state_text_elipsis_get(self.edje.obj, self.part,
                                                 self.name, self.value)
diff --git a/efl/elementary/cnp_callbacks.pxi b/efl/elementary/cnp_callbacks.pxi
index fdd6520..f2542e7 100644
--- a/efl/elementary/cnp_callbacks.pxi
+++ b/efl/elementary/cnp_callbacks.pxi
@@ -246,7 +246,7 @@ cdef void py_elm_drag_done_cb(void *data, Evas_Object *obj, 
Eina_Bool accepted)
 
     :param data: Application specific data
     :param obj: The object where the drag started
-    :param accepted: TRUE if the droppped-data is accepted on drop
+    :param accepted: TRUE if the dropped-data is accepted on drop
 
     .. versionadded:: 1.8
 
diff --git a/efl/elementary/configuration.pyx b/efl/elementary/configuration.pyx
index 79f3ea8..1fe10b3 100644
--- a/efl/elementary/configuration.pyx
+++ b/efl/elementary/configuration.pyx
@@ -287,7 +287,7 @@ cdef class Configuration(object):
 
     property scroll_thumbscroll_hold_threshold:
         """The number of pixels the range which can be scrolled,
-        while the scroller is holded.
+        while the scroller is held.
 
         :type: int
 
diff --git a/efl/elementary/datetime_elm.pyx b/efl/elementary/datetime_elm.pyx
index 6f333bd..9536484 100644
--- a/efl/elementary/datetime_elm.pyx
+++ b/efl/elementary/datetime_elm.pyx
@@ -253,6 +253,7 @@ from cpython cimport PyUnicode_AsUTF8String
 
 from efl.eo cimport _object_mapping_register
 from efl.utils.conversions cimport _ctouni
+from efl.utils.deprecated cimport DEPRECATED
 from efl.evas cimport Object as evasObject
 from object cimport Object
 
@@ -605,10 +606,15 @@ cdef class Datetime(Object):
     def callback_changed_del(self, func):
         self._callback_del("changed", func)
 
+    @DEPRECATED("1.10", "Use callback_language_changed_add instead.")
     def callback_languge_changed_add(self, func, *args, **kwargs):
         """Whenever system locale changes, this signal is sent."""
         self._callback_add("language,changed", func, *args, **kwargs)
 
+    def callback_language_changed_add(self, func, *args, **kwargs):
+        """Whenever system locale changes, this signal is sent."""
+        self._callback_add("language,changed", func, *args, **kwargs)
+
     def callback_language_changed_del(self, func):
         self._callback_del("language,changed", func)
 
diff --git a/efl/elementary/diskselector.pyx b/efl/elementary/diskselector.pyx
index 49a5bb1..b306214 100644
--- a/efl/elementary/diskselector.pyx
+++ b/efl/elementary/diskselector.pyx
@@ -60,7 +60,7 @@ Scrollable Interface
 
 This widget supports the scrollable interface.
 
-If you wish to control the scolling behaviour using these functions,
+If you wish to control the scrolling behaviour using these functions,
 inherit both the widget class and the
 :py:class:`~efl.elementary.scroller.Scrollable` class
 using multiple inheritance, for example::
diff --git a/efl/elementary/gengrid_item_class.pxi 
b/efl/elementary/gengrid_item_class.pxi
index 050cbf1..7cfd865 100644
--- a/efl/elementary/gengrid_item_class.pxi
+++ b/efl/elementary/gengrid_item_class.pxi
@@ -50,7 +50,7 @@ cdef class GengridItemClass:
 
         :param content_get_func: if provided will override the behavior
             defined by :py:func:`content_get()` in this class. Its purpose is
-            to return the icon object to be used (swalloed) by a
+            to return the icon object to be used (swallowed) by a
             given part and row. This function should have the
             signature:
             ``func(obj, part, item_data) -> obj``
diff --git a/efl/elementary/gengrid_widget.pxi 
b/efl/elementary/gengrid_widget.pxi
index c3e233c..0eb4599 100644
--- a/efl/elementary/gengrid_widget.pxi
+++ b/efl/elementary/gengrid_widget.pxi
@@ -477,7 +477,7 @@ cdef class Gengrid(Object):
     #     Set a item container (list, genlist, grid) as source of drag
 
     #     :param tm_to_anim: Time period to wait before start animation.
-    #     :param tm_to_drag: Time period to wait before start draggind.
+    #     :param tm_to_drag: Time period to wait before start dragging.
     #     :param itemgetcb: Callback to get Evas object for item at (x,y)
     #     :param data_get:  Callback to get drag info
 
@@ -561,7 +561,7 @@ cdef class Gengrid(Object):
     # def drop_item_container_del(self):
     #     """
 
-    #     Removes a container from list of drop tragets.
+    #     Removes a container from list of drop targets.
 
     #     :raise RuntimeError: if deleting drop target failed.
 
diff --git a/efl/elementary/genlist.pyx b/efl/elementary/genlist.pyx
index e9f1df2..0029f7d 100644
--- a/efl/elementary/genlist.pyx
+++ b/efl/elementary/genlist.pyx
@@ -203,9 +203,9 @@ scroller will scroll horizontally. Otherwise items are 
expanded to
 fill the width of the viewport of the scroller. If it is
 ELM_LIST_LIMIT, items will be expanded to the viewport width
 if larger than the item, but genlist widget with is
-limited to the largest item. D not use ELM_LIST_LIMIT mode with homogenous
+limited to the largest item. D not use ELM_LIST_LIMIT mode with homogeneous
 mode turned on. ELM_LIST_COMPRESS can be combined with a different style
-that uses edjes' ellipsis feature (cutting text off like this: "tex...").
+that uses Edje's ellipsis feature (cutting text off like this: "tex...").
 
 Items will only call their selection func and callback when first becoming
 selected. Any further clicks will do nothing, unless you enable always
@@ -226,7 +226,7 @@ Scrollable Interface
 
 This widget supports the scrollable interface.
 
-If you wish to control the scolling behaviour using these functions,
+If you wish to control the scrolling behaviour using these functions,
 inherit both the widget class and the
 :py:class:`~efl.elementary.scroller.Scrollable` class
 using multiple inheritance, for example::
diff --git a/efl/elementary/genlist_item_class.pxi 
b/efl/elementary/genlist_item_class.pxi
index 584a8ee..dbada0b 100644
--- a/efl/elementary/genlist_item_class.pxi
+++ b/efl/elementary/genlist_item_class.pxi
@@ -50,7 +50,7 @@ cdef class GenlistItemClass(object):
 
         :param content_get_func: if provided will override the behavior
             defined by :py:func:`content_get()` in this class. Its purpose is
-            to return the icon object to be used (swalloed) by a
+            to return the icon object to be used (swallowed) by a
             given part and row. This function should have the
             signature:
             ``func(obj, part, item_data) -> obj``
@@ -64,7 +64,7 @@ cdef class GenlistItemClass(object):
 
         :param del_func: if provided will override the behavior
             defined by ``delete()`` in this class. Its purpose is to be
-            called when row is deleted, thus finalizing resouces
+            called when row is deleted, thus finalizing resources
             and similar. This function should have the signature:
             ``func(obj, part, item_data)``
 
diff --git a/efl/elementary/genlist_widget.pxi 
b/efl/elementary/genlist_widget.pxi
index 6a3c1d3..1d1758a 100644
--- a/efl/elementary/genlist_widget.pxi
+++ b/efl/elementary/genlist_widget.pxi
@@ -646,7 +646,7 @@ cdef class Genlist(Object):
         left. This is true of course if the selection was made by
         clicking an unfocusable area in an item or selecting it with a
         key movement. Clicking on a focusable widget inside an item will
-        couse this particular item to get focus as usual.
+        cause this particular item to get focus as usual.
 
         .. versionadded:: 1.8
 
@@ -670,7 +670,7 @@ cdef class Genlist(Object):
     #     Set a item container (list, genlist, grid) as source of drag
 
     #     :param tm_to_anim: Time period to wait before start animation.
-    #     :param tm_to_drag: Time period to wait before start draggind.
+    #     :param tm_to_drag: Time period to wait before start dragging.
     #     :param itemgetcb: Callback to get Evas object for item at (x,y)
     #     :param data_get:  Callback to get drag info
 
@@ -754,7 +754,7 @@ cdef class Genlist(Object):
     # def drop_item_container_del(self):
     #     """
 
-    #     Removes a container from list of drop tragets.
+    #     Removes a container from list of drop targets.
 
     #     :raise RuntimeError: if deleting drop target failed.
 
diff --git a/efl/elementary/glview.pyx b/efl/elementary/glview.pyx
index 156b27c..ba15ab0 100644
--- a/efl/elementary/glview.pyx
+++ b/efl/elementary/glview.pyx
@@ -235,7 +235,7 @@ cdef class GLView(LayoutClass):
         By default, the render policy is set to 
ELM_GLVIEW_RENDER_POLICY_ON_DEMAND.
         This policy is set such that during the render loop, glview is only
         redrawn if it needs to be redrawn. (i.e. when it is visible) If the 
policy
-        is set to ELM_GLVIEWW_RENDER_POLICY_ALWAYS, it redraws regardless of
+        is set to ELM_GLVIEW_RENDER_POLICY_ALWAYS, it redraws regardless of
         whether it is visible or needs redrawing.
 
         """
diff --git a/efl/elementary/icon.pyx b/efl/elementary/icon.pyx
index bd2abb3..333cab7 100644
--- a/efl/elementary/icon.pyx
+++ b/efl/elementary/icon.pyx
@@ -222,7 +222,7 @@ cdef class Icon(Image):
         :raise RuntimeWarning: when setting the standard name fails.
 
         :return bool: For 1.7 compatibility standard_set() returns a bool value
-            that tells whether setting the standard name was succesful or not.
+            that tells whether setting the standard name was successful or not.
 
         .. versionchanged:: 1.8
             Raises RuntimeWarning when setting the standard name fails,
diff --git a/efl/elementary/layout_class.pyx b/efl/elementary/layout_class.pyx
index 138e867..d5e890d 100644
--- a/efl/elementary/layout_class.pyx
+++ b/efl/elementary/layout_class.pyx
@@ -314,7 +314,7 @@ cdef class LayoutClass(Object):
         """Remove a signal-triggered callback from a given layout widget.
 
         This function removes the **last** callback attached to a signal
-        emitted by the undelying Edje object, with parameters *emission*,
+        emitted by the underlying Edje object, with parameters *emission*,
         ``source`` and ``func`` matching exactly those passed to a previous
         call to :py:meth:`~efl.elementary.object.Object.signal_callback_add`.
         The data that was passed to this call will be returned.
@@ -853,7 +853,7 @@ cdef class LayoutClass(Object):
             <const char *>part_name if part_name is not None else NULL))
 
     property edje_object_can_access:
-        """Set accessibility to all texblock(text) parts in the layout object
+        """Set accessibility to all textblock(text) parts in the layout object
 
         Makes it possible for all textblock(text) parts in the layout to have
         accessibility.
diff --git a/efl/elementary/map.pyx b/efl/elementary/map.pyx
index b492fb2..c3f0ace 100644
--- a/efl/elementary/map.pyx
+++ b/efl/elementary/map.pyx
@@ -304,7 +304,7 @@ cdef void _map_name_callback(void *data, Evas_Object *map, 
Elm_Map_Name *name) w
 cdef class MapRoute(object):
     """
 
-    This class represent a calcolated route.
+    This class represents a calculated route.
 
     A route will be traced by point on coordinates to point on coordinates
     , using the route service set with :py:func:`Map.source_set()`.
@@ -773,17 +773,17 @@ cdef class MapOverlayClass(MapOverlay):
     property members:
         """ The overlay members of the class overlay.
 
-        The group overlays are virtualy overlays. Those are shown and hidden
+        The group overlays are virtually overlays. Those are shown and hidden
         dynamically. You can add callback to the class overlay. If one of the
         group overlays in this class is clicked, callback will be called and
         return a virtual group overlays.
 
         You can change the state (hidden, paused, etc.) or set the content
-        or icon of the group overlays by chaning the state of the class 
overlay.
+        or icon of the group overlays by changing the state of the class 
overlay.
 
         :type: list of :py:class:`MapOverlay`
 
-        .. warning:: Do not modifty the group overlay itself.
+        .. warning:: Do not modify the group overlay itself.
 
         """
         def __get__(self):
@@ -1637,7 +1637,7 @@ cdef class Map(Object):
         self._callback_add("clicked", func, *args, **kwargs)
 
     def callback_clicked_del(self, func):
-        """ Delete a previuosly attached callback """
+        """ Delete a previously attached callback """
         self._callback_del("clicked", func)
 
     def callback_clicked_double_add(self, func, *args, **kwargs):
@@ -1645,7 +1645,7 @@ cdef class Map(Object):
         self._callback_add("clicked,double", func, *args, **kwargs)
 
     def callback_clicked_double_del(self, func):
-        """ Delete a previuosly attached callback """
+        """ Delete a previously attached callback """
         self._callback_del("clicked,double", func)
 
     def callback_press_add(self, func, *args, **kwargs):
@@ -1653,7 +1653,7 @@ cdef class Map(Object):
         self._callback_add("press", func, *args, **kwargs)
 
     def callback_press_del(self, func):
-        """ Delete a previuosly attached callback """
+        """ Delete a previously attached callback """
         self._callback_del("press", func)
 
     def callback_longpressed_add(self, func, *args, **kwargs):
@@ -1661,7 +1661,7 @@ cdef class Map(Object):
         self._callback_add("longpressed", func, *args, **kwargs)
 
     def callback_longpressed_del(self, func):
-        """ Delete a previuosly attached callback """
+        """ Delete a previously attached callback """
         self._callback_del("longpressed", func)
 
     def callback_scroll_add(self, func, *args, **kwargs):
@@ -1669,7 +1669,7 @@ cdef class Map(Object):
         self._callback_add("scroll", func, *args, **kwargs)
 
     def callback_scroll_del(self, func):
-        """ Delete a previuosly attached callback """
+        """ Delete a previously attached callback """
         self._callback_del("scroll", func)
 
     def callback_scroll_drag_start_add(self, func, *args, **kwargs):
@@ -1677,7 +1677,7 @@ cdef class Map(Object):
         self._callback_add("scroll,drag,start", func, *args, **kwargs)
 
     def callback_scroll_drag_start_del(self, func):
-        """ Delete a previuosly attached callback """
+        """ Delete a previously attached callback """
         self._callback_del("scroll,drag,start", func)
 
     def callback_scroll_drag_stop_add(self, func, *args, **kwargs):
@@ -1685,7 +1685,7 @@ cdef class Map(Object):
         self._callback_add("scroll,drag,stop", func, *args, **kwargs)
 
     def callback_scroll_drag_stop_del(self, func):
-        """ Delete a previuosly attached callback """
+        """ Delete a previously attached callback """
         self._callback_del("scroll,drag,stop", func)
 
     def callback_scroll_anim_start_add(self, func, *args, **kwargs):
@@ -1693,7 +1693,7 @@ cdef class Map(Object):
         self._callback_add("scroll,anim,start", func, *args, **kwargs)
 
     def callback_scroll_anim_start_del(self, func):
-        """ Delete a previuosly attached callback """
+        """ Delete a previously attached callback """
         self._callback_del("scroll,anim,start", func)
 
     def callback_scroll_anim_stop_add(self, func, *args, **kwargs):
@@ -1701,7 +1701,7 @@ cdef class Map(Object):
         self._callback_add("scroll,anim,stop", func, *args, **kwargs)
 
     def callback_scroll_anim_stop_del(self, func):
-        """ Delete a previuosly attached callback """
+        """ Delete a previously attached callback """
         self._callback_del("scroll,anim,stop", func)
 
     def callback_zoom_start_add(self, func, *args, **kwargs):
@@ -1709,7 +1709,7 @@ cdef class Map(Object):
         self._callback_add("zoom,start", func, *args, **kwargs)
 
     def callback_zoom_start_del(self, func):
-        """ Delete a previuosly attached callback """
+        """ Delete a previously attached callback """
         self._callback_del("zoom,start", func)
 
     def callback_zoom_stop_add(self, func, *args, **kwargs):
@@ -1717,7 +1717,7 @@ cdef class Map(Object):
         self._callback_add("zoom,stop", func, *args, **kwargs)
 
     def callback_zoom_stop_del(self, func):
-        """ Delete a previuosly attached callback """
+        """ Delete a previously attached callback """
         self._callback_del("zoom,stop", func)
 
     def callback_zoom_change_add(self, func, *args, **kwargs):
@@ -1725,7 +1725,7 @@ cdef class Map(Object):
         self._callback_add("zoom,change", func, *args, **kwargs)
 
     def callback_zoom_change_del(self, func):
-        """ Delete a previuosly attached callback """
+        """ Delete a previously attached callback """
         self._callback_del("zoom,change", func)
 
     def callback_tile_load_add(self, func, *args, **kwargs):
@@ -1733,7 +1733,7 @@ cdef class Map(Object):
         self._callback_add("tile,load", func, *args, **kwargs)
 
     def callback_tile_load_del(self, func):
-        """ Delete a previuosly attached callback """
+        """ Delete a previously attached callback """
         self._callback_del("tile,load", func)
 
     def callback_tile_loaded_add(self, func, *args, **kwargs):
@@ -1741,7 +1741,7 @@ cdef class Map(Object):
         self._callback_add("tile,loaded", func, *args, **kwargs)
 
     def callback_tile_loaded_del(self, func):
-        """ Delete a previuosly attached callback """
+        """ Delete a previously attached callback """
         self._callback_del("tile,loaded", func)
 
     def callback_tile_loaded_fail_add(self, func, *args, **kwargs):
@@ -1749,7 +1749,7 @@ cdef class Map(Object):
         self._callback_add("tile,loaded,fail", func, *args, **kwargs)
 
     def callback_tile_loaded_fail_del(self, func):
-        """ Delete a previuosly attached callback """
+        """ Delete a previously attached callback """
         self._callback_del("tile,loaded,fail", func)
 
     def callback_route_load_add(self, func, *args, **kwargs):
@@ -1757,7 +1757,7 @@ cdef class Map(Object):
         self._callback_add("route,load", func, *args, **kwargs)
 
     def callback_route_load_del(self, func):
-        """ Delete a previuosly attached callback """
+        """ Delete a previously attached callback """
         self._callback_del("route,load", func)
 
     def callback_route_loaded_add(self, func, *args, **kwargs):
@@ -1765,7 +1765,7 @@ cdef class Map(Object):
         self._callback_add("route,loaded", func, *args, **kwargs)
 
     def callback_route_loaded_del(self, func):
-        """ Delete a previuosly attached callback """
+        """ Delete a previously attached callback """
         self._callback_del("route,loaded", func)
 
     def callback_route_loaded_fail_add(self, func, *args, **kwargs):
@@ -1773,7 +1773,7 @@ cdef class Map(Object):
         self._callback_add("route,loaded,fail", func, *args, **kwargs)
 
     def callback_route_loaded_fail_del(self, func):
-        """ Delete a previuosly attached callback """
+        """ Delete a previously attached callback """
         self._callback_del("route,loaded,fail", func)
 
     def callback_name_load_add(self, func, *args, **kwargs):
@@ -1781,7 +1781,7 @@ cdef class Map(Object):
         self._callback_add("name,load", func, *args, **kwargs)
 
     def callback_name_load_del(self, func):
-        """ Delete a previuosly attached callback """
+        """ Delete a previously attached callback """
         self._callback_del("name,load", func)
 
     def callback_name_loaded_add(self, func, *args, **kwargs):
@@ -1789,7 +1789,7 @@ cdef class Map(Object):
         self._callback_add("name,loaded", func, *args, **kwargs)
 
     def callback_name_loaded_del(self, func):
-        """ Delete a previuosly attached callback """
+        """ Delete a previously attached callback """
         self._callback_del("name,loaded", func)
 
     def callback_name_loaded_fail_add(self, func, *args, **kwargs):
@@ -1797,7 +1797,7 @@ cdef class Map(Object):
         self._callback_add("name,loaded,fail", func, *args, **kwargs)
 
     def callback_name_loaded_fail_del(self, func):
-        """ Delete a previuosly attached callback """
+        """ Delete a previously attached callback """
         self._callback_del("name,loaded,fail", func)
 
     def callback_overlay_clicked_add(self, func, *args, **kwargs):
@@ -1805,7 +1805,7 @@ cdef class Map(Object):
         self._callback_add("overlay,clicked", func, *args, **kwargs)
 
     def callback_overlay_clicked_del(self, func):
-        """ Delete a previuosly attached callback """
+        """ Delete a previously attached callback """
         self._callback_del("overlay,clicked", func)
 
     def callback_overlay_del_add(self, func, *args, **kwargs):
@@ -1813,7 +1813,7 @@ cdef class Map(Object):
         self._callback_add("overlay,del", func, *args, **kwargs)
 
     def callback_overlay_del_del(self, func):
-        """ Delete a previuosly attached callback """
+        """ Delete a previously attached callback """
         self._callback_del("overlay,del", func)
 
     def callback_loaded_add(self, func, *args, **kwargs):
@@ -1821,7 +1821,7 @@ cdef class Map(Object):
         self._callback_add("loaded", func, *args, **kwargs)
 
     def callback_loaded_del(self, func):
-        """ Delete a previuosly attached callback """
+        """ Delete a previously attached callback """
         self._callback_del("loaded", func)
 
     def callback_language_changed_add(self, func, *args, **kwargs):
@@ -1829,7 +1829,7 @@ cdef class Map(Object):
         self._callback_add("language,changed", func, *args, **kwargs)
 
     def callback_language_changed_del(self, func):
-        """ Delete a previuosly attached callback """
+        """ Delete a previously attached callback """
         self._callback_del("language,changed", func)
 
     def callback_focused_add(self, func, *args, **kwargs):
diff --git a/efl/elementary/naviframe.pyx b/efl/elementary/naviframe.pyx
index 693dfb0..1524332 100644
--- a/efl/elementary/naviframe.pyx
+++ b/efl/elementary/naviframe.pyx
@@ -64,7 +64,7 @@ them are supported:
 
 - ``basic``   - views are switched sliding horizontally, one after the other
 - ``overlap`` - like the previous one, but the previous view stays at its place
-  and is ovelapped by the new
+  and is overlapped by the new
 
 
 This widget emits the following signals, besides the ones sent from
diff --git a/efl/elementary/object.pyx b/efl/elementary/object.pyx
index b9658b2..9dabe40 100644
--- a/efl/elementary/object.pyx
+++ b/efl/elementary/object.pyx
@@ -1977,7 +1977,7 @@ cdef class Object(evasObject):
     #     Set a item container (list, genlist, grid) as source of drag
 
     #     :param tm_to_anim: Time period to wait before start animation.
-    #     :param tm_to_drag: Time period to wait before start draggind.
+    #     :param tm_to_drag: Time period to wait before start dragging.
     #     :param itemgetcb: Callback to get Evas_Object pointer for item at 
(x,y)
     #     :param data_get:  Callback to get drag info
     #     :return: Returns EINA_TRUE, if successful, or EINA_FALSE if not.
@@ -2035,7 +2035,7 @@ cdef class Object(evasObject):
     # def drop_item_container_del(self):
     #     """
 
-    #     Removes a container from list of drop tragets.
+    #     Removes a container from list of drop targets.
 
     #     :param obj: The container object
     #     :return: Returns EINA_TRUE, if successful, or EINA_FALSE if not.
diff --git a/efl/elementary/photocam.pyx b/efl/elementary/photocam.pyx
index fbaef05..a1f2878 100644
--- a/efl/elementary/photocam.pyx
+++ b/efl/elementary/photocam.pyx
@@ -62,7 +62,7 @@ Scrollable Interface
 
 This widget supports the scrollable interface.
 
-If you wish to control the scolling behaviour using these functions,
+If you wish to control the scrolling behaviour using these functions,
 inherit both the widget class and the
 :py:class:`~efl.elementary.scroller.Scrollable` class
 using multiple inheritance, for example::
diff --git a/efl/elementary/radio.pyx b/efl/elementary/radio.pyx
index 5b4401d..0d6d113 100644
--- a/efl/elementary/radio.pyx
+++ b/efl/elementary/radio.pyx
@@ -31,7 +31,7 @@ icon object. While it's possible to have a group of only one 
radio they,
 are normally used in groups of two or more.
 
 Radio objects are grouped in a slightly different, compared to other UI
-toolkits. There is no seperate group name/id to remember or manage. The
+toolkits. There is no separate group name/id to remember or manage. The
 members represent the group, there are the group. To make a group, use
 :py:meth:`Radio.group_add` and pass existing radio object and the new radio
 object.
diff --git a/efl/elementary/slideshow.pyx b/efl/elementary/slideshow.pyx
index 8f7227b..1a71e77 100644
--- a/efl/elementary/slideshow.pyx
+++ b/efl/elementary/slideshow.pyx
@@ -167,7 +167,7 @@ cdef class SlideshowItemClass (object):
 
     :param get_func: if provided will override the behavior
         defined by :py:func:`get()` in this class. Its purpose is
-        to return the icon object to be used (swalloed) by a
+        to return the icon object to be used (swallowed) by a
         given part and row. This function should have the
         signature:
         ``func(obj, item_data) -> obj``
diff --git a/efl/elementary/toolbar.pyx b/efl/elementary/toolbar.pyx
index 838335b..2e0d3a3 100644
--- a/efl/elementary/toolbar.pyx
+++ b/efl/elementary/toolbar.pyx
@@ -53,7 +53,7 @@ Scrollable Interface
 
 This widget supports the scrollable interface.
 
-If you wish to control the scolling behaviour using these functions,
+If you wish to control the scrolling behaviour using these functions,
 inherit both the widget class and the
 :py:class:`~efl.elementary.scroller.Scrollable` class
 using multiple inheritance, for example::
diff --git a/efl/elementary/window.pxd b/efl/elementary/window.pxd
index d1b0e2d..11dc863 100644
--- a/efl/elementary/window.pxd
+++ b/efl/elementary/window.pxd
@@ -126,7 +126,7 @@ cdef extern from "Elementary.h":
     Eina_Bool                
elm_win_wm_rotation_manual_rotation_done_get(const Evas_Object *obj)
     void                     
elm_win_wm_rotation_manual_rotation_done(Evas_Object *obj)
 
-    # X specific call - wont't work on non-x engines (return 0)
+    # X specific call - won't work on non-x engines (return 0)
     Ecore_X_Window           elm_win_xwindow_get(const Evas_Object *obj)
     # TODO: Ecore_Wl_Window         *elm_win_wl_window_get(const Evas_Object 
*obj)
 
diff --git a/efl/elementary/window.pyx b/efl/elementary/window.pyx
index 6843c03..8ec7b44 100644
--- a/efl/elementary/window.pyx
+++ b/efl/elementary/window.pyx
@@ -1047,7 +1047,7 @@ cdef class Window(Object):
         return elm_win_layer_get(self.obj)
 
     def norender_push(self):
-        """This pushes (incriments) the norender counter on the window
+        """This pushes (increments) the norender counter on the window
 
         There are some occasions where you wish to suspend rendering on a 
window.
         You may be "sleeping" and have nothing to update and do not want 
animations
@@ -1111,7 +1111,7 @@ cdef class Window(Object):
         """This manually asks evas to render the window now
 
         You should NEVER call this unless you really know what you are doing 
and
-        why. Never call this unless you are asking for performance degredation
+        why. Never call this unless you are asking for performance degradation
         and possibly weird behavior. Windows get automatically rendered when 
the
         application goes idle so there is never a need to call this UNLESS you
         have enabled "norender" mode.
diff --git a/efl/ethumb/efl.ethumb_client.pyx b/efl/ethumb/efl.ethumb_client.pyx
index 8eb495f..8c4939f 100644
--- a/efl/ethumb/efl.ethumb_client.pyx
+++ b/efl/ethumb/efl.ethumb_client.pyx
@@ -444,7 +444,7 @@ cdef class Client:
 
         This will create an edje object that will have image swallowed
         in. This can be used to simulate Polaroid or wood frames in
-        the generated image. Remeber it is bad to modify the original
+        the generated image. Remember it is bad to modify the original
         contents of thumbnails, but sometimes it's useful to have it
         composited and avoid runtime overhead.
 
diff --git a/efl/evas/efl.evas.pyx b/efl/evas/efl.evas.pyx
index 58fbead..5bf3807 100644
--- a/efl/evas/efl.evas.pyx
+++ b/efl/evas/efl.evas.pyx
@@ -286,13 +286,13 @@ class EvasLoadError(Exception):
         elif code == enums.EVAS_LOAD_ERROR_DOES_NOT_EXIST:
             msg = "File (or file path) does not exist"
         elif code == enums.EVAS_LOAD_ERROR_PERMISSION_DENIED:
-            msg = "Permission deinied to an existing file (or path)"
+            msg = "Permission denied to an existing file (or path)"
         elif code == enums.EVAS_LOAD_ERROR_RESOURCE_ALLOCATION_FAILED:
             msg = "Allocation of resources failure prevented load"
         elif code == enums.EVAS_LOAD_ERROR_CORRUPT_FILE:
             msg = "File corrupt (but was detected as a known format)"
         elif code == enums.EVAS_LOAD_ERROR_UNKNOWN_FORMAT:
-            msg = "File is not a known format"
+            msg = "File is not in a known format"
         self.code = code
         self.file = filename
         self.key = key
diff --git a/efl/evas/efl.evas_object.pxi b/efl/evas/efl.evas_object.pxi
index 2eaec20..de8cae7 100644
--- a/efl/evas/efl.evas_object.pxi
+++ b/efl/evas/efl.evas_object.pxi
@@ -131,7 +131,7 @@ cdef class Object(Eo):
     - Modulating color
 
     Clips respects the hierarchy: the minimum area and the composed color
-    will be used used at the end, if one object is not visible, othe lower
+    will be used used at the end, if one object is not visible, the lower
     objects (clipped by it) will not be visible as well. Clipping is the
     recommended way of doing fade out/in effect, instead of changing object's
     color, clip it to a rectangle and change its color: this will work as
@@ -183,7 +183,7 @@ cdef class Object(Eo):
 
         name_str = "name=%s, " % name if name is not NULL else ""
 
-        return ("<%s (%sgeometry=(%d, %d, %d, %d), color=(%d, %d, %d, %d), "
+        return ("<%s (%s geometry=(%d, %d, %d, %d), color=(%d, %d, %d, %d), "
                 "layer=%s, clip=%s, visible=%s)>") % (
             Eo.__repr__(self),
             name_str,
diff --git a/efl/evas/efl.evas_object_box.pxi b/efl/evas/efl.evas_object_box.pxi
index 6748fe5..8a62591 100644
--- a/efl/evas/efl.evas_object_box.pxi
+++ b/efl/evas/efl.evas_object_box.pxi
@@ -178,7 +178,7 @@ cdef class Box(Object):
             _Evas_Object_Box_Api::insert_before smart function.
 
         """
-        # TODO: raise exception if unsuccesful
+        # TODO: raise exception if unsuccessful
         evas_object_box_insert_before(self.obj, child.obj, reference.obj)
 
     def insert_after(self, Object child, Object reference):
@@ -206,7 +206,7 @@ cdef class Box(Object):
             _Evas_Object_Box_Api::insert_after smart function.
 
         """
-        # TODO: raise exception if unsuccesful
+        # TODO: raise exception if unsuccessful
         evas_object_box_insert_after(self.obj, child.obj, reference.obj)
 
     def insert_at(self, Object child, unsigned int pos):
diff --git a/efl/evas/efl.evas_object_image.pxi 
b/efl/evas/efl.evas_object_image.pxi
index 5d50b68..f4977d9 100644
--- a/efl/evas/efl.evas_object_image.pxi
+++ b/efl/evas/efl.evas_object_image.pxi
@@ -750,7 +750,7 @@ cdef class Image(Object):
 
     #     :param pixels: The pixel source to be imported.
     #     :type pixels: Evas_Pixel_Import_Source *
-    #     :return: Whether the import was succesful
+    #     :return: Whether the import was successful
     #     :rtype: bool
 
     #     This function imports pixels from a given source to a given canvas 
image.
diff --git a/efl/evas/efl.evas_object_smart.pxi 
b/efl/evas/efl.evas_object_smart.pxi
index 45ec663..34bd06e 100644
--- a/efl/evas/efl.evas_object_smart.pxi
+++ b/efl/evas/efl.evas_object_smart.pxi
@@ -771,7 +771,7 @@ cdef class ClippedSmartObject(SmartObject):
     object size), this means that you should clip this object to another
     object clipper to get its contents restricted. This is the default
     because many times what we want are contents that can overflow SmartObject
-    boudaries (ie: members with animations coming in from outside).
+    boundaries (ie: members with animations coming in from outside).
 
     :ivar clipper: the internal object used for clipping. You shouldn't
        mess with it.
diff --git a/efl/evas/efl.evas_object_table.pxi 
b/efl/evas/efl.evas_object_table.pxi
index 6354a79..b4fb531 100644
--- a/efl/evas/efl.evas_object_table.pxi
+++ b/efl/evas/efl.evas_object_table.pxi
@@ -236,7 +236,7 @@ cdef class Table(Object):
 
             columns and rows are virtual entities, one can specify a table
             with a single object that takes 4 columns and 5 rows. The only
-            difference for a single cell table is that paddings will be
+            difference for a single cell table is that padding will be
             accounted proportionally.
 
         """
diff --git a/efl/evas/efl.evas_object_textgrid.pxi 
b/efl/evas/efl.evas_object_textgrid.pxi
index 69a9217..36b017d 100644
--- a/efl/evas/efl.evas_object_textgrid.pxi
+++ b/efl/evas/efl.evas_object_textgrid.pxi
@@ -359,7 +359,7 @@ cdef class Textgrid(Object):
         """The retrieve color to the given palette at the given index of the 
given textgrid object.
 
         :param pal: The type of the palette to set the color.
-        :param idx: The index of the paletter to wich the color is stored.
+        :param idx: The index of the palette to which the color is stored.
         :rtype: (int **r**, int **g**, int **b**, int **a**)
 
         This function retrieves the color for the palette of type **pal** at 
the
diff --git a/include/efl.ethumb.enums.pxd b/include/efl.ethumb.enums.pxd
index 2c6f6e4..ce27729 100644
--- a/include/efl.ethumb.enums.pxd
+++ b/include/efl.ethumb.enums.pxd
@@ -21,6 +21,6 @@ cdef extern from "Ethumb.h":
 
     ctypedef enum Ethumb_Thumb_Aspect:
         ETHUMB_THUMB_KEEP_ASPECT # keep original proportion between width and 
height
-        ETHUMB_THUMB_IGNORE_ASPECT # ignore aspect and foce it to match 
thumbnail's width and height
+        ETHUMB_THUMB_IGNORE_ASPECT # ignore aspect and force it to match 
thumbnail's width and height
         ETHUMB_THUMB_CROP # keep aspect but crop (cut) the largest dimension
 
diff --git a/include/efl.evas.enums.pxd b/include/efl.evas.enums.pxd
index c0afd03..396a492 100644
--- a/include/efl.evas.enums.pxd
+++ b/include/efl.evas.enums.pxd
@@ -144,7 +144,7 @@ cdef extern from "Evas.h":
     ctypedef enum Evas_Display_Mode:
         # object's display mode type related with compress/expand or etc mode
         EVAS_DISPLAY_MODE_NONE # Default mode
-        EVAS_DISPLAY_MODE_COMPRESS # Use this mode want to give comppress 
display mode hint to object
+        EVAS_DISPLAY_MODE_COMPRESS # Use this mode want to give compress 
display mode hint to object
         EVAS_DISPLAY_MODE_EXPAND # Use this mode want to give expand display 
mode hint to object
         EVAS_DISPLAY_MODE_DONT_CHANGE # Use this mode when object should not 
change display mode
 
diff --git a/tests/edje/test_03_external.py b/tests/edje/test_03_external.py
index a5dad0f..ef164f5 100644
--- a/tests/edje/test_03_external.py
+++ b/tests/edje/test_03_external.py
@@ -64,16 +64,16 @@ class TestElementaryExternal(unittest.TestCase):
         elm_as = self.theme.part_external_object_get("ext_elm_actionslider")
         self.assertIsInstance(elm_as, Actionslider)
 
-        # check values setted in edc (from external)
+        # check values set in edc (from external)
         
self.assertEqual(self.theme.part_external_param_get("ext_elm_actionslider", 
"label"), "ActionSlideR")
 
-        # check values setted in edc (from object)
+        # check values set in edc (from object)
         self.assertEqual(elm_as.text, "ActionSlideR")
 
         # do params set
         self.theme.part_external_param_set("ext_elm_actionslider", "label", 
"new text")
 
-        # recheck setted values
+        # recheck set values
         
self.assertEqual(self.theme.part_external_param_get("ext_elm_actionslider", 
"label"), "new text")
         self.assertEqual(elm_as.text, "new text")
 
@@ -111,7 +111,7 @@ class TestElementaryExternal(unittest.TestCase):
         elm_clock = self.theme.part_external_object_get("ext_elm_clock")
         self.assertIsInstance(elm_clock, Clock)
 
-        # check values setted in edc (from external)
+        # check values set in edc (from external)
         self.assertEqual(self.theme.part_external_param_get("ext_elm_clock", 
"hours"), 23)
         self.assertEqual(self.theme.part_external_param_get("ext_elm_clock", 
"minutes"), 58)
         self.assertEqual(self.theme.part_external_param_get("ext_elm_clock", 
"seconds"), 59)
@@ -119,7 +119,7 @@ class TestElementaryExternal(unittest.TestCase):
         self.assertEqual(self.theme.part_external_param_get("ext_elm_clock", 
"am/pm"), True)
         self.assertEqual(self.theme.part_external_param_get("ext_elm_clock", 
"show seconds"), True)
 
-        # check values setted in edc (from object)
+        # check values set in edc (from object)
         self.assertEqual(elm_clock.time, (23, 58, 59))
         self.assertEqual(elm_clock.edit, True)
         self.assertEqual(elm_clock.show_am_pm, True)
@@ -133,7 +133,7 @@ class TestElementaryExternal(unittest.TestCase):
         self.theme.part_external_param_set("ext_elm_clock", "am/pm", False)
         self.theme.part_external_param_set("ext_elm_clock", "show seconds", 
False)
 
-        # recheck setted values
+        # recheck set values
         self.assertEqual(elm_clock.time, (2, 3, 4))
         self.assertEqual(elm_clock.edit, False)
         self.assertEqual(elm_clock.show_am_pm, False)
diff --git a/tests/edje/test_05_decorators.py b/tests/edje/test_05_decorators.py
index 69383a7..1b7d8b3 100644
--- a/tests/edje/test_05_decorators.py
+++ b/tests/edje/test_05_decorators.py
@@ -60,7 +60,7 @@ class TestEdjeDecoratedCallbacks(unittest.TestCase):
         ecore.Timer(0.1, lambda: o.part_text_set("label", "asd"))
         ecore.Timer(0.1, lambda: o.part_text_set("label", "asd2"))
 
-        # ask the edje obj to send a messagge, two times
+        # ask the edje obj to send a message, two times
         ecore.Timer(0.1, lambda: o.signal_emit("emit,message", ""))
         ecore.Timer(0.1, lambda: o.signal_emit("emit,message", ""))
 
diff --git a/tests/evas/test_04_object_box.py b/tests/evas/test_04_object_box.py
index dba361b..c07e764 100644
--- a/tests/evas/test_04_object_box.py
+++ b/tests/evas/test_04_object_box.py
@@ -33,7 +33,7 @@ class TestBoxBasics(unittest.TestCase):
         self.assertEqual(box1.pos, pos)
         box1.delete()
 
-        # cleate box2 using geometry
+        # create box2 using geometry
         box2 = evas.Box(self.canvas, name="box2", color=color, 
geometry=geometry)
         self.assertEqual(box2.name, "box2")
         self.assertEqual(box2.color, color)

diff --git a/efl/emotion/efl.emotion.pyx b/efl/emotion/efl.emotion.pyx
index a39070f..6d07cdf 100644
--- a/efl/emotion/efl.emotion.pyx
+++ b/efl/emotion/efl.emotion.pyx
@@ -184,7 +184,7 @@ cdef class Emotion(evasObject):
 
     :param evas: The canvas where the object will be added to.
     :type evas: efl.evas.Canvas
-    :param module_name: name of the engien to use (gstreamer, xine, vlc or 
generic)
+    :param module_name: name of the engine to use (gstreamer, xine, vlc or 
generic)
     :param module_params: Extra parameters, module specific
     :param size: (w, h)
     :param pos: (x, y)
@@ -389,7 +389,7 @@ cdef class Emotion(evasObject):
           EVAS_ASPECT_CONTROL_HORIZONTAL size hint.
         - ``EMOTION_ASPECT_KEEP_HEIGHT`` respect the video aspect ratio, 
fitting
           the video height inside the object height. This option is similar to
-          EVAS_ASPECT_CONTROL_VERTIAL size hint.
+          EVAS_ASPECT_CONTROL_VERTICAL size hint.
         - ``EMOTION_ASPECT_KEEP_BOTH`` respect the video aspect ratio, fitting 
both
           its width and height inside the object area. This option is similar 
to
           EVAS_ASPECT_CONTROL_BOTH size hint. It's the effect called 
letterboxing.
@@ -447,16 +447,16 @@ cdef class Emotion(evasObject):
             <const char *>file_name if file_name is not None else NULL)
 
     property priority:
         """ Raise the priority of an object so it will have a priviledged
         access to hardware resource.
 
         Hardware have a few dedicated hardware pipeline that process the video
         at no cost for the CPU. Especially on SoC, you mostly have one (on
         mobile phone SoC) or two (on Set Top Box SoC) when Picture in Picture
         is needed. And most application just have a few video stream that 
really
-        deserve high frame rate, hiogh quality output. That's why this call is 
for.
+        deserve high frame rate, high quality output. That's why this call is 
for.
 
-        .. note:: If Emotion can't acquire a priviledged hardware ressource,
+        .. note:: If Emotion can't acquire a privileged hardware resource,
                   it will fallback to the no-priority path. This work on the
                   first asking first get basis system.
 
@@ -1038,7 +1038,7 @@ cdef class Emotion(evasObject):
     def last_position_load(self):
         """ Load the last known position if available
 
-        By using Xattr, Emotion is able, if the system permitt it, to store
+        By using Xattr, Emotion is able, if the system permits it, to store
         and retrieve the latest position. It should trigger some smart
         callback to let the application know when it succeed or fail.
         Every operation is fully asynchronous and not linked to the actual
@@ -1050,7 +1050,7 @@ cdef class Emotion(evasObject):
         emotion_object_last_position_load(self.obj)
 
     def last_position_save(self):
-        """ Save the lastest position if possible
+        """ Save the last position if possible
 
         :see: :py:meth:`last_position_load`
 
@@ -1063,7 +1063,7 @@ cdef class Emotion(evasObject):
         """ Get the actual image object (:py:class:`efl.evas.Object`) of the
         emotion object.
 
-        This function is usefull when you want to get a direct access to the 
pixels.
+        This function is useful when you want to get a direct access to the 
pixels.
 
         .. versionadded:: 1.8
 
@@ -1102,7 +1102,7 @@ cdef class Emotion(evasObject):
 
             func(object, *args, **kwargs)
 
-        .. note:: Any extra params givento the function (both positional
+        .. note:: Any extra params given to the function (both positional
                   and keyword arguments) will be passed back in the
                   callback function.
 
@@ -447,16 +447,16 @@ cdef class Emotion(evasObject):
 
     property priority:
-        """ Raise the priority of an object so it will have a priviledged
+        """ Raise the priority of an object so it will have a privileged
         access to hardware resource.
 
-- 


Reply via email to